@@ -206,52 +206,3 @@ readUntilPrompt feed prompts = go BS.empty
       if foundPrompt acc'
         then return acc'
         else go acc'
-
-
-{-
-readUntilPrompt :: IO BS.ByteString -> [String] -> IO BS.ByteString
-readUntilPrompt feed prompts = go BS.empty
-  where
-    promptBsList = map BS.pack prompts
-
-    foundPrompt acc = any (`BS.isInfixOf` acc) promptBsList
-
-    go acc = do
-      chunk <- feed
-      when ("\ESC[6n" `BS.isInfixOf` chunk) $ do
-        E.throwString "Unsupported: Detected cursor position report request (ESC[6n)."
-
-      -- let txt = ANSI.stripAnsiEscapeCodes $ TE.decodeUtf8With TEE.lenientDecode chunk
-      let txt = TE.decodeUtf8With TEE.lenientDecode chunk
-      hPutStrLn stderr $ "[INFO] chunk:\n" ++ T.unpack txt
-
-      let acc' = BS.append acc chunk
-      if foundPrompt acc'
-        then return acc'
-        else go acc'
-
-
-
-readUntilPrompt :: Pty -> [String] -> IO BS.ByteString
-readUntilPrompt pms prompts = go BS.empty T.empty
-  where
-    promptTextList = map T.pack prompts
-
-    foundPrompt :: T.Text -> Bool
-    foundPrompt txt = any (`T.isInfixOf` txt) promptTextList
-
-    go accBs accTxt = do
-      chunk <- readPty pms
-      let txt = ANSI.stripAnsiEscapeCodes $ TE.decodeUtf8With TEE.lenientDecode chunk
-      hPutStrLn stderr $ "[INFO] chunk:\n" ++ T.unpack txt
-
-      when ("\ESC[6n" `BS.isInfixOf` chunk) $ do
-        hPutStrLn stderr "[INFO] Detected cursor position report request, replying with ESC[1;1R"
-        writePty pms (DBS.pack ([0x1B :: Word8, 0x5B :: Word8] ++ map (fromIntegral . ord) "0;0R"))
-
-      let accBs' = BS.append accBs chunk
-          accTxt' = T.append accTxt txt
-      if foundPrompt accTxt'
-        then return accBs'
-        else go accBs' accTxt'
--}
